@@ -2,7 +2,7 @@
                           cmdlineoptions.cpp  -  description
                              -------------------
     begin                : Sun Oct 13 2007
-    copyright            : (C) 2007-2017 by Andre Simon
+    copyright            : (C) 2007-2018 by Andre Simon
     email                : andre.simon1@gmx.de
  ***************************************************************************/
 
@@ -36,7 +36,7 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 using namespace std;  
     
 const Arg_parser::Option options[] = {
-    { 'a', "anchors",    Arg_parser::no },
+    { 'a', "anchors",    Arg_parser::maybe },
     { 'd', "doc-title",  Arg_parser::yes },
     { 'e', "encoding",   Arg_parser::yes },
     { 'f', "fragment",   Arg_parser::no  },
@@ -70,7 +70,8 @@ const Arg_parser::Option options[] = {
     { 'N', "no-trailing-nl",  Arg_parser::no  },
     { 'C', "no-version-info", Arg_parser::no  },
     { 'k', "ignore-clear",    Arg_parser::no  },
-    
+    { 'y', "derived-styles",  Arg_parser::no  },
+   
     {  0,  0,           Arg_parser::no  }
 };
 
@@ -90,6 +91,9 @@ CmdLineOptions::CmdLineOptions( const int argc, const char *argv[] ):
     opt_omit_trailing_cr(false),
     opt_omit_version_info(false),
     opt_ignoreClear(false),
+    opt_applyDynStyles(false),
+    opt_genDynStyles(false),
+    opt_funny_anchors(false),
     encodingName("ISO-8859-1"),
     font("Courier New"),
     fontSize("10pt"),
@@ -158,6 +162,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         */
         case 'a':
             opt_anchors = true;
+            if ( arg=="self" ) opt_funny_anchors=true;
             break;
         case 'B':
             outputType = ansifilter::BBCODE;
@@ -227,7 +232,7 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
             outDirectory = validateDirPath( arg );
             break;
         case 'w':
-            wrapLineLen=atoi(arg.c_str())-1;
+            wrapLineLen=atoi(arg.c_str());
             break;
         case 'W':
             opt_wrapNoNum=true;
@@ -256,6 +261,9 @@ void CmdLineOptions::parseRuntimeOptions( const int argc, const char *argv[], bo
         case 'k':
             opt_ignoreClear=true;
             break;
+        case 'y':
+            opt_applyDynStyles=true;
+            break;
         default:
             cerr << "ansifilter: option parsing failed" << endl;
         }
@@ -416,6 +424,11 @@ bool CmdLineOptions::addAnchors() const
 {
     return opt_anchors;
 }
+bool CmdLineOptions::addFunnyAnchors() const
+{
+    return opt_funny_anchors;
+}
+
 bool CmdLineOptions::omitEncoding() const
 {
     return StringTools::lowerCase(encodingName)=="none";
@@ -429,6 +442,11 @@ bool CmdLineOptions::omitVersionInfo() const
 {
     return opt_omit_version_info;
 }
+bool CmdLineOptions::applyDynStyles() const {
+    return opt_applyDynStyles;
+}
+    
+    
 string CmdLineOptions::getDocumentTitle() const
 {
     return docTitle;
