@@ -2,7 +2,7 @@
                           main.cpp  -  description
                              -------------------
 
-    copyright            : (C) 2007-2017 by Andre Simon
+    copyright            : (C) 2007-2018 by Andre Simon
     email                : andre.simon1@gmx.de
 
    Highlight is a universal source code to HTML converter. Syntax highlighting
@@ -66,7 +66,7 @@ void ANSIFilterApp::printHelp()
     cout << "  -R, --rtf              Output RTF\n";
     cout << "  -B, --bbcode           Output BBCode\n";
     cout << "\nFormat options:\n";
-    cout << "  -a, --anchors          Add HTML line anchors (assumes -l)\n";
+    cout << "  -a, --anchors(=self)   Add HTML line anchors (opt: self referencing, assumes -l)\n";
     cout << "  -d, --doc-title        Set HTML/LaTeX document title\n";
     cout << "  -e, --encoding         Set HTML/RTF encoding (must match input file encoding)\n";
     cout << "  -f, --fragment         Omit HTML header and footer\n";
@@ -81,6 +81,7 @@ void ANSIFilterApp::printHelp()
     cout << "      --no-trailing-nl   Omit trailing newline\n";
     cout << "      --no-version-info  Omit version info comment\n";
     cout << "      --wrap-no-numbers  Omit line numbers of wrapped lines (assumes -l)\n";
+    cout << "      --derived-styles   Output dynamic stylesheets (assumes -H)\n";
     
     cout << "\nANSI art options:\n";
     cout << "      --art-cp437        Parse codepage 437 ANSI art (HTML and RTF output)\n";
@@ -159,18 +160,19 @@ int ANSIFilterApp::run( const int argc, const char *argv[] )
         generator->setPreformatting(ansifilter::WRAP_SIMPLE, options.getWrapLineLength());
         generator->setShowLineNumbers(options.showLineNumbers());
         generator->setWrapNoNumbers(!options.wrapNoNumbers());
-        generator->setAddAnchors(options.addAnchors());
+        generator->setAddAnchors(options.addAnchors(), options.addFunnyAnchors());
         generator->setParseCodePage437(options.parseCP437());
         generator->setParseAsciiBin(options.parseAsciiBin());
         generator->setParseAsciiTundra(options.parseAsciiTundra());
         generator->setIgnoreClearSeq(options.ignoreClearSeq());
+        generator->setApplyDynStyles(options.applyDynStyles());
 
         generator->setAsciiArtSize(options.getAsciiArtWidth(), options.getAsciiArtHeight());
         generator->setOmitTrailingCR(options.omitTrailingCR());
         generator->setOmitVersionInfo(options.omitVersionInfo());
         
         ansifilter::ParseError error = generator->generateFile(inFileList[i], outFilePath);
-
+        
         if (error==ansifilter::BAD_INPUT) {
             std::cerr << "could not read input: " << inFileList[i] << "\n";
             failure=true;
@@ -180,6 +182,12 @@ int ANSIFilterApp::run( const int argc, const char *argv[] )
         }
         ++i;
     }
+    
+    if (options.applyDynStyles() && !failure) {
+        string styleStyleSheetPath = outDirectory + "derived_styles.css";
+        generator->printDynamicStyleFile(styleStyleSheetPath);
+    }
+    
     return (failure) ? EXIT_FAILURE : EXIT_SUCCESS;
 }
 
